@@ -1,7 +1,7 @@
 import functools
 
 from .authentication_util import verify_pubsub_token, verify_authorization
-from secretmanager import secret_manager_service
+from ..secretmanager import secret_manager_service
 from flask import request
 
 
